{*******************************************************************************
 *                               Etikett Version 1.1                           *
 *                (c) 2002 Ulrich Borghoff    Gymnasium Wilnsdorf              *
 *                           eMail: sum-delphi@web.de                          *
 * *****************************************************************************
 * Diese Komponenten Version drfte unter Delphi ab Version ab 4 laufen        *
 *******************************************************************************
 * Bitte ndern Sie diese Datei nicht ab, sondern teilen den Entwicklern Ihre  *
 * Verbesserungsvorschlge oder Fehler (und ggf. deren Berichtigung) mit.      *
 *                                                                             *
 * Danke fr Ihre Mitarbeit.                                                   *
 *******************************************************************************}


unit mEtikett;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, mSuM;

type
  tAusrichtung=(LINKSBUENDIG,ZENTRIERT,RECHTSBUENDIG);

  TEtikett = class(TCustomLabel)

 private

    procedure setzeZustand(pAktiv:Wahrheitswert);
    procedure setzeSichtbarkeit(pSichtbar:Wahrheitswert);
    procedure setzeText(pInhalt:Zeichenkette);
    function ausrichtung:tAusrichtung;


  public
    constructor Create(AOwner: TComponent); override;
    constructor init(pLinks,pOben, pBreite, pHoehe: Zahl);  overload;
    constructor init(pLinks,pOben, pBreite, pHoehe: Zahl; pInhalt:Zeichenkette);  overload;

    procedure setzePosition(pLinks, pOben : Zahl); virtual;
    procedure setzeGroesse(pBreite, pHoehe : Zahl); virtual;

    function links:Zahl;  virtual;
    function oben:Zahl; virtual;
    function breite:Zahl;  virtual;
    function hoehe:Zahl; virtual;

    procedure verstecke; virtual;
    procedure zeige; virtual;
    function IstSichtbar:Wahrheitswert; virtual;

    procedure aktiviere; virtual;
    procedure deaktiviere; virtual;
    function istAktiviert: Wahrheitswert; virtual;

    procedure setzeFokus; virtual;
    function besitztFokus: Wahrheitswert; virtual;

    procedure setzeInhalt(pInhalt:Zeichenkette); overload; virtual;
    procedure setzeInhalt(pInhalt:Zahl); overload; virtual;

    function InhaltIstZeichenkette:Wahrheitswert; virtual;
    function InhaltIstZahl:Wahrheitswert; virtual;
    function InhaltIstGanzeZahl:Wahrheitswert; virtual;

    function inhaltAlsText:Zeichenkette; virtual;

    function inhaltAlsZahl:Zahl; virtual;
    function inhaltAlsGanzeZahl:GanzeZahl; virtual;

    procedure setzeSchriftart(pArt:Zeichenkette);
    procedure setzeSchriftGroesse(pGroesse:GanzeZahl);
    procedure setzeSchriftFarbe(pFarbe:GanzeZahl);
    procedure setzeSchriftStil(pStil:GanzeZahl);
    procedure setzeAusrichtung(pAusrichtung:tAusrichtung);

    procedure gibFrei; virtual;

   published

    property _Inhalt: Zeichenkette read inhaltAlsText
                             write setzeText;
    property _IstAktiviert : Wahrheitswert read istAktiviert write SetzeZustand;
    property _IstSichtbar : Wahrheitswert read IstSichtbar write SetzeSichtbarkeit;
    property _Ausrichtung: tAusrichtung read ausrichtung write setzeAusrichtung default LINKSBUENDIG;

    property font;
  end;

procedure Register;

implementation

constructor tEtikett.Create(AOwner: TComponent);
begin
  inherited create(AOwner);
  self.name:='hat'+self.name;
end;

constructor tEtikett.init(pLinks,pOben, pBreite, pHoehe: Zahl);
begin
  inherited create(screen.activeForm);
  ControlStyle := [csSetCaption, csOpaque, csDoubleClicks];
  self.setzePosition(pLinks,pOben);
  self.setzeGroesse(pBreite,pHoehe);
  self.setzeText('');
  self.parent:=screen.activeForm;
end;

constructor tEtikett.init(pLinks,pOben, pBreite, pHoehe: Zahl; pInhalt:Zeichenkette);
begin
  self.init(pLinks,pOben, pBreite, pHoehe);
  self.setzeInhalt(pInhalt);
end;

procedure tEtikett.setzePosition(pLinks, pOben:Zahl);
begin
 self.left:=round(pLinks);
 self.Top:=round(pOben);
end;

procedure tEtikett.setzeGroesse(pBreite, pHoehe:Zahl);
begin
 self.Width:=round(pBreite);
 self.Height:=round(pHoehe);
end;

function tEtikett.links:Zahl;
begin
 result:=self.left
end;

function tEtikett.oben:Zahl;
begin
  result:=self.top;
end;

function tEtikett.breite:Zahl;
begin
  result:=self.width;
end;

function tEtikett.hoehe:Zahl;
begin
  result:=self.height;
end;

procedure tEtikett.verstecke;
begin
 self.visible:=false;
end;

procedure tEtikett.zeige;
begin
 self.visible:=true;
end;

function tEtikett.IstSichtbar:Wahrheitswert;
begin
  result:=self.visible;
end;

procedure tEtikett.aktiviere;
begin
 self.enabled:=true;
end;

procedure tEtikett.deaktiviere;
begin
 self.enabled:=false;
end;

function tEtikett.istAktiviert: Wahrheitswert;
begin
 result:=self.enabled;
end;

procedure tEtikett.setzeFokus;
begin
 // Etikett kann keinen FoKus besitzen.
end;

function tEtikett.besitztFokus: Wahrheitswert;
begin
 result:=false;
end;

procedure tEtikett.setzeText(pInhalt:Zeichenkette);
begin
 self.caption:=pInhalt;
 self.update;
end;

procedure tEtikett.setzeInhalt(pInhalt:Zeichenkette);
begin
 self.caption:=pInhalt;
 self.update;
end;

procedure tEtikett.setzeInhalt(pInhalt:Zahl);
begin
  self.setzeInhalt(floatToStr(pInhalt));
end;

function tEtikett.InhaltIstZeichenkette:Wahrheitswert;
begin
  result:=true;
end;

function tEtikett.InhaltIstZahl:Wahrheitswert;
  var lWert: Zahl;
      lcode : integer;
begin
  val(self.inhaltAlsText,lWert,lCode);
  result:=(lcode=0);
end;

function tEtikett.InhaltIstGanzeZahl:Wahrheitswert;
  var lWert: GanzeZahl;
      code : integer;
begin
  val(self.inhaltAlsText,lWert,Code);
  result:=(code=0);
end;

function tEtikett.InhaltAlsText:Zeichenkette;
begin
 result := self.caption;
end;

function tEtikett.inhaltAlsZahl:Zahl;
begin
  if self.InhaltistZahl then result:=strTofloat(self.inhaltAlsText)
  else
  begin
    MessageDlg('Eingabe keine Zahl.',mtError,[mbOK],0);
    result:=0;
  end;
end;

function tEtikett.inhaltAlsGanzeZahl:GanzeZahl;
begin
  if self.InhaltIstGanzeZahl then result:=strToInt(self.inhaltAlsText)
  else
  begin
    MessageDlg('Eingabe keine ganze Zahl.',mtError,[mbOK],0);
    result:=0;
  end;
end;

procedure tEtikett.setzeSchriftart(pArt:Zeichenkette);
begin
  self.Font.Name:=pArt;
end;

procedure tEtikett.setzeSchriftGroesse(pGroesse:GanzeZahl);
begin
  self.Font.size:=pGroesse;
end;

procedure tEtikett.setzeSchriftFarbe(pFarbe:GanzeZahl);
begin
  self.Font.Color:=SuMfarbumrechnung(pFarbe); {farbumrechnung aus mSuM}
end;

procedure tEtikett.setzeSchriftStil(pStil:GanzeZahl);
begin
  self.Font.Style:=SuMstilumrechnung(pStil);  {stilumrechnung aus mSuM}
end;

procedure tEtikett.gibFrei;
begin
 self.destroy;
end;

// private

procedure tEtikett.setzeZustand(pAktiv:Wahrheitswert);
begin
 self.enabled:=pAktiv;
end;

procedure tEtikett.setzeSichtbarkeit(pSichtbar:Wahrheitswert);
begin
 self.visible:=pSichtbar;
end;

procedure tEtikett.setzeAusrichtung(pAusrichtung:tAusrichtung);
begin
 case pAusrichtung of
   RECHTSBUENDIG : self.Alignment:=taRightJustify;
   LINKSBUENDIG : self.Alignment:=taLeftJustify;
   ZENTRIERT : self.Alignment:=taCenter;
 end;
end;

 function tEtikett.ausrichtung:tAusrichtung;
 begin
   if self.Alignment=taCenter then result:=ZENTRIERT;
   if self.Alignment=taRightJustify then result:=RECHTSBUENDIG;
   if self.Alignment=taLeftJustify then result:=LINKSBUENDIG;
 end;

// Registrierung

procedure Register;
begin
  RegisterComponents('Schule', [tEtikett]);
end;


end.
